readability.
ARI(txt.file, parameters = c(asl = 0.5, awl = 4.71, const = 21.43), ...)kRp.tagged-class,
a character vector which must be be
a valid path to a file containing the text to be analyzed,
or a list of text features. If the latter, calculation
is done by readability.num.readability for details.kRp.readability-class.
readability,
which by default calculates all possible indices,
this function will only calculate the index value.If parameters="NRI",
the simplified parameters from the Navy Readability Indexes are used, if set to
ARI="simple", the simplified formula is calculated.
This formula doesn't need syllable count.
Smith, E.A. & Senter, R.J. (1967). Automated readability index. AMRL-TR-66-22. Wright-Paterson AFB, Ohio: Aerospace Medical Division.
## Not run:
# ARI(tagged.text)
# ## End(Not run)
Run the code above in your browser using DataLab