Learn R Programming

koRpus (version 0.13-8)

dale.chall: Readability: Dale-Chall Readability Formula

Description

This is just a convenient wrapper function for readability.

Usage

dale.chall(
  txt.file,
  word.list,
  parameters = c(const = 64, dword = 0.95, asl = 0.69),
  ...
)

Value

An object of class kRp.readability.

Arguments

txt.file

Either an object of class kRp.text, a character vector which must be be a valid path to a file containing the text to be analyzed, or a list of text features. If the latter, calculation is done by readability.num.

word.list

A vector or matrix (with exactly one column) which defines familiar words. For valid results the long Dale-Chall list with about 3000 words should be used.

parameters

A numeric vector with named magic numbers, defining the relevant parameters for the index.

...

Further valid options for the main function, see readability for details.

Details

Calculates the New Dale-Chall Readability Formula. In contrast to readability, which by default calculates all possible indices, this function will only calculate the index value.

If parameters="PSK", the parameters by Powers-Sumner-Kearl (1958) are used, and if parameters="old", the original parameters by Dale-Chall (1948), respectively.

This formula doesn't need syllable count.

Examples

Run this code
if (FALSE) {
dale.chall(tagged.text, word.list=new.dale.chall.wl)
}

Run the code above in your browser using DataLab