Learn R Programming

koRpus (version 0.13-8)

dickes.steiwer: Readability: Dickes-Steiwer Handformel

Description

This is just a convenient wrapper function for readability.

Usage

dickes.steiwer(
  txt.file,
  parameters = c(const = 235.95993, awl = 73.021, asl = 12.56438, ttr = 50.03293),
  case.sens = FALSE,
  ...
)

Value

An object of class kRp.readability.

Arguments

txt.file

Either an object of class kRp.text, a character vector which must be be a valid path to a file containing the text to be analyzed, or a list of text features. If the latter, calculation is done by readability.num.

parameters

A numeric vector with named magic numbers, defining the relevant parameters for the index.

case.sens

Logical, whether types should be counted case sensitive.

...

Further valid options for the main function, see readability for details.

Details

This function calculates the shortcut formula by Dickes-Steiwer. In contrast to readability, which by default calculates all possible indices, this function will only calculate the index value.

This formula doesn't need syllable count.

Examples

Run this code
if (FALSE) {
  dickes.steiwer(tagged.text)
}

Run the code above in your browser using DataLab