flesch.kincaid: Readability: Flesch-Kincaid Grade Level
Description
This is just a convenient wrapper function for readability.
Usage
flesch.kincaid(
txt.file,
hyphen = NULL,
parameters = c(asl = 0.39, asw = 11.8, const = 15.59),
...
)
Value
An object of class kRp.readability.
Arguments
- txt.file
Either an object of class kRp.text,
a character vector which must be be
a valid path to a file containing the text to be analyzed,
or a list of text features. If the latter, calculation
is done by readability.num.
- hyphen
An object of class kRp.hyphen. If NULL,
the text will be hyphenated automatically.
- parameters
A numeric vector with named magic numbers,
defining the relevant parameters for the index.
- ...
Further valid options for the main function,
see readability for details.
Details
Calculates the Flesch-Kincaid grade level. In contrast to readability,
which by default calculates all possible indices,
this function will only calculate the index value.
Examples
Run this codeif (FALSE) {
flesch.kincaid(tagged.text)
}
Run the code above in your browser using DataLab