hyphen.
manage.hyph.pat(hyph.pattern, get = NULL, set = NULL, rm = NULL, word = NULL, min.length = 3, rm.hyph = TRUE)kRp.hyph.pat,
or a valid language abbreviation for patterns included in this package.NULL,
returns an object of class kRp.hyph.pat-class.
The same is true if set or rm are set and hyph.pattern is itself an object of that class; if you refer to a language
instead,
pattern changes will be done internally for the running session and take effect immediately.
The get argument will return a caracter vector, and word a data frame.
NULL,
the corresponding action is done in the following order, and every additional discarded:
getSearches the pattern set for a given word part
setAdds or replaces a pattern in the set (duplicates are removed)
rmRemoves a word part and its pattern from the set
wordHyphenates a word and returns all parts examined as well as all matching patterns
If all action arguments are NULL,
manage.hyph.pat returns the full pattern object.
kRp.hyph.pat-class,
hyphen
## Not run:
# manage.hyph.pat("en", set="r3ticl")
# manage.hyph.pat("en", get="rticl")
# manage.hyph.pat("en", word="article")
# manage.hyph.pat("en", rm="rticl")
# ## End(Not run)
Run the code above in your browser using DataLab