kRp.corp.freq-class.read.corp.custom(corpus, format = "file", fileEncoding = "UTF-8",
quiet = TRUE, caseSens = TRUE, log.base = 10, ...)kRp.tagged (then the column "token"<FALSE, short status messages will be shown.FALSE,
all tokens will be matched in their lower case form.log for details.tokenize function.kRp.corp.freq-class.kRp.corp.freq-class,
so it can be used for frequency analysis by
other functions of this package.kRp.corp.freq-classru.corp <- read.corp.custom("~/mydata/corpora/russian_corpus/")Run the code above in your browser using DataLab