set.kRp.env: A function to set information on your koRpus environmenton
Description
The function set.kRp.env can be called once before
any of the analysing functions. It writes information on
your session environment regarding the koRpus package,
e.g. path to a local TreeTagger installation, to a hidden
environment.
Usage
set.kRp.env(...)
Arguments
...
Named parameters to set in the koRpus
environment. Valid arguments are: [object Object],[object Object],[object Object],[object Object] To explicitly unset a
value again, set it to an empty character string (e.g.,
lang="").
Value
Returns an invisible NULL.
Details
To get the contents of the hitten environment, the
function get.kRp.env
can be used.