readability.farr.jenkins.paterson(txt.file, hyphen = NULL,
parameters = c(const = -31.517, asl = 1.015, monsy = 1.599),
...)kRp.tagged-class, a character
vector which must be be a valid path to a file containing
the text to be analyzed, or a list of text features. If
the latter, cNULL, the text will be hyphenated automatically."PSK".readability for
details.kRp.readability-class.readability, which by
default calculates all possible indices, this function
will only calculate the index value. If parameters="PSK", the revised parameters by
Powers-Sumner-Kearl (1958) are used.
Powers, R.D, Sumner, W.A, & Kearl, B.E. (1958). A recalculation of four adult readability formulas, Journal of Educational Psychology, 49(2), 99--105.
fleschfarr.jenkins.paterson(tagged.text)Run the code above in your browser using DataLab