hyphen.manage.hyph.pat(hyph.pattern, get = NULL, set = NULL, rm = NULL,
word = NULL, min.length = 3, rm.hyph = TRUE)kRp.hyph.pat,
or a valid language abbreviation for patterns included in this package.NULL,
returns an object of class kRp.hyph.pat-class.
The same is true if set or rm are set and hyph.pattern is itself an object of that class; if you refer to a language
instead,
pattern changes will be done internally for the running session and take effect immediately.
The get argument will return a caracter vector, and word a data frame.manage.hyph.patNULL,
the corresponding action is done in the following order, and every additional discarded:
getsetrmwordkRp.hyph.pat-class,
hyphenmanage.hyph.pat("en", set="r3ticl")
manage.hyph.pat("en", get="rticl")
manage.hyph.pat("en", word="article")
manage.hyph.pat("en", rm="rticl")Run the code above in your browser using DataLab