The function should enable you to perform a basic text
corpus frequency analysis. That is, not just to import
analysis results like LCC files, but to import the corpus
material itself. The resulting object is of class
kRp.corp.freq-class, so it can be
used for frequency analysis by other functions of this
package.