kRp.corp.freq-class.
read.corp.custom(corpus, ...)
"read.corp.custom"(corpus, quiet = TRUE, caseSens = TRUE, log.base = 10, ...)
"read.corp.custom"(corpus, format = "file", quiet = TRUE, caseSens = TRUE, log.base = 10, tagger = "kRp.env", force.lang = NULL, ...)
"read.corp.custom"(corpus, quiet = TRUE, caseSens = TRUE, log.base = 10, ...)kRp.tagged (then the column "token" of
the "TT.res" slot is used).tokenize function.FALSE, short status messages will be shown.FALSE,
all tokens will be matched in their lower case form.log for details.txt.file is already of class kRp.tagged-class. Defaults to tagger="kRp.env" to get the settings by
get.kRp.env. Set to "tokenize" to use tokenize.kRp.corp.freq-class.
kRp.corp.freq-class,
so it can be used for frequency analysis by
other functions and methods of this package.
kRp.corp.freq-class
## Not run:
# ru.corp <- read.corp.custom("~/mydata/corpora/russian_corpus/")
# ## End(Not run)
Run the code above in your browser using DataLab