kRp.corp.freq-class.read.corp.custom(corpus, ...)## S3 method for class 'kRp.taggedText':
read.corp.custom(corpus, quiet = TRUE,
caseSens = TRUE, log.base = 10, ...)
## S3 method for class 'character':
read.corp.custom(corpus, format = "file",
quiet = TRUE, caseSens = TRUE, log.base = 10, tagger = "kRp.env",
force.lang = NULL, ...)
## S3 method for class 'list':
read.corp.custom(corpus, quiet = TRUE, caseSens = TRUE,
log.base = 10, ...)
kRp.tagged (then the column "token"<tokenize function.FALSE, short status messages will be shown.FALSE,
all tokens will be matched in their lower case form.log for details.txt.file is already of class kRp.tagged-class. Defaults to tagger="kRp.env" to get the settings bkRp.corp.freq-class.kRp.corp.freq-class,
so it can be used for frequency analysis by
other functions and methods of this package.kRp.corp.freq-classru.corp <- read.corp.custom("~/mydata/corpora/russian_corpus/")Run the code above in your browser using DataLab